/* eslint-disable no-undef */
import { useEffect } from 'react';
import PropTypes from 'prop-types';
import { useGoogleMap } from '@react-google-maps/api';
import { DISABLED_MAP_INTERACTION_OPTIONS, ENABLED_MAP_INTERACTION_OPTIONS } from './settings.js';
function GoogleMapsDrawer(_ref) {
  var _google;
  var _ref$drawing = _ref.drawing,
    drawing = _ref$drawing === void 0 ? false : _ref$drawing,
    onStopDrawing = _ref.onStopDrawing,
    _ref$polylineOptions = _ref.polylineOptions,
    polylineOptions = _ref$polylineOptions === void 0 ? {} : _ref$polylineOptions;
  var mapsLibrary = (_google = google) == null ? void 0 : _google.maps; // Looking for global google object
  var mapRef = useGoogleMap(); // Get map instance from context

  useEffect(function () {
    if (drawing) {
      startDrawing();
    } else {
      stopDrawing();
    }
  }, [drawing]); // eslint-disable-line react-hooks/exhaustive-deps

  var draw = function draw(_ref2) {
    var polyline = _ref2.polyline;
    mapsLibrary.event.addListener(mapRef, 'mousemove', function (event) {
      return polyline.getPath().push(event.latLng);
    });
  };
  var clearListeners = function clearListeners() {
    mapsLibrary.event.clearListeners(mapRef, 'mousemove');
    mapsLibrary.event.clearListeners(mapRef, 'mousedown');
    mapsLibrary.event.clearListeners(mapRef, 'mouseup');
  };

  // This will convert the path from MVCArray<LatLng> to a LatLngLiteral array
  var convertMVCArrayToLatLngLiteralArray = function convertMVCArrayToLatLngLiteralArray(_ref3) {
    var polyline = _ref3.polyline;
    var path = polyline.getPath().getArray();
    return path.map(function (_ref4) {
      var lat = _ref4.lat,
        lng = _ref4.lng;
      return {
        lat: lat(),
        lng: lng()
      };
    });
  };
  var stopDrawing = function stopDrawing(_temp) {
    var _ref5 = _temp === void 0 ? {} : _temp,
      polyline = _ref5.polyline;
    if (!mapsLibrary || !mapRef || !polyline) return [];
    var path = convertMVCArrayToLatLngLiteralArray({
      polyline: polyline
    });

    // Remove the polyline from the map
    polyline.setMap(null);
    clearListeners();
    mapRef.setOptions(ENABLED_MAP_INTERACTION_OPTIONS);
    onStopDrawing({
      path: path
    });
  };
  var startDrawing = function startDrawing() {
    if (!mapsLibrary || !mapRef) return [];
    mapRef.setOptions(DISABLED_MAP_INTERACTION_OPTIONS);
    var polyline = new mapsLibrary.Polyline({
      map: mapRef,
      clickable: false,
      options: polylineOptions
    });
    mapsLibrary.event.addListener(mapRef, 'touchmove', function (e) {
      return e.preventDefault();
    });
    mapsLibrary.event.addListener(mapRef, 'mousedown', function () {
      return draw({
        polyline: polyline
      });
    });
    mapsLibrary.event.addListener(mapRef, 'mouseup', function () {
      return stopDrawing({
        polyline: polyline
      });
    });
  };

  // No need to render anything, just listen to drawing events and draw on the map
  return null;
}
GoogleMapsDrawer.displayName = 'GoogleMapsDrawer';
GoogleMapsDrawer.propTypes = {
  drawing: PropTypes.bool,
  onStopDrawing: PropTypes.func.isRequired,
  polylineOptions: PropTypes.object
};
export default GoogleMapsDrawer;